import requests
import yaml

__version__ = '0.0.1'


class ApiClient(object):

    def __init__(self, url, key, version='api'):

        if not url:
            raise RuntimeError('WAVES_URL environment variable not set')

        if not key:
            raise RuntimeError('API_KEY environment variable not set')

        self.waves_url = url
        self.api_key = key
        self.api_version = version
        self.session = requests.Session()
        self._workflow = None
        # login salvando token

    def workflow(self, identifier):
        url = self._build_url('workflows/{}'.format(identifier))
        response = requests.get(
            url,
            headers=self._get_headers(),
        )
        if not response.status_code == 200:
            return "Erro: {}: {}".format(response, response.content)
        self._workflow = response.json()
        self._execution = None
        return self

    def get_inputs(self):
        if self._execution:
            return self._execution['inputs']
        elif self._workflow:
            self._inputs = {}
            for item in self._workflow['definition']['inputs']:
                self._inputs[item['name']] = '' if item.get('required') else None
                if item.get('default'):
                    self._inputs[item['name']] = item.get('default')
            return self._inputs
        return {}

    def execution(self, identifier=None):
        if not identifier:
            self._execution = None
            self._inputs = None
            return self

        url = self._build_url('executions/{}'.format(identifier))
        response = requests.get(
            url,
            headers=self._get_headers(),
        )
        if not response.status_code == 200:
            return "Erro: {}: {}".format(response, response.content)

        self._execution = response.json()
        self._inputs = self._execution['inputs']
        self._workflow = self._execution['workflow']
        return self

    def create(self, inputs=None):
        if self._execution and not inputs:
            return self.run(
                workflow_identifier=self._workflow['identifier'],
                inputs=self._inputs,
            )

        elif self._workflow and inputs:
            return self.run(
                workflow_identifier=self._workflow['identifier'],
                inputs=inputs,
            )
        self._results = None
        return {
            "message": "Nothing to do",
        }

    def register_businesstask(self, btask_content):
        url = self._build_url('business-tasks')
        response = requests.post(
            url,
            headers=self._get_headers(),
            data=btask_content.encode('utf-8'))
        if not response.status_code == 201:
            return "Erro : {}: {}".format(response, response.content)
        return response.json()

    def publish_businesstask(self, btask_content):

        definition = yaml.load(btask_content, Loader=yaml.FullLoader)
        identifier = '{}@{}'.format(
            definition.get('name'), definition.get('version', 'latest'))

        url = self._build_url('business-tasks/{}/publish'.format(identifier))

        response = requests.put(
            url,
            headers=self._get_headers())

        if not response.status_code == 200:
            return "Erro : {}: {}".format(response, response.content)
        return response.json()

    def create_workflow(self, workflow_content):
        url = self._build_url('workflows')
        response = requests.post(
            url,
            headers=self._get_headers(),
            data=workflow_content.encode('utf-8'))
        if not response.status_code == 201:
            return "Erro : {}: {}".format(response, response.content)
        return response.json()

    def run(self, workflow_identifier, inputs):
        """
        Create a new execution for the workflow identifier
        """
        url = self._build_url('executions')
        new_execution = {
            "workflow_identifier": workflow_identifier,
            "inputs": inputs,
        }
        response = requests.post(
            url,
            headers=self._get_headers(content_type='application/json'),
            json=new_execution)

        if not response.status_code == 201:
            return "Erro : {}: {}".format(response, response.content)
        self._results = response.json()
        return self._results

    def list_workers(self):
        """
        list active workers
        """
        url = self._build_url('workers')
        response = requests.get(
            url,
            headers=self._get_headers(),
        )

        if not response.status_code == 200:
            return "Erro: {}: {}".format(response, response.content)
        return response.json()

    def _get_headers(self, content_type='application/x-yaml'):
        headers = {
            'User-Agent': 'wavescli/{}'.format(__version__),
            'Content-Type': content_type,
            'X-API-KEY': self.api_key
        }
        return headers

    def _build_url(self, endpoint):
        return '/'.join([self.waves_url, self.api_version, endpoint])


class ApiError(RuntimeError):

    def __init__(self, response):
        message = 'status={} data={}'.format(
            response.status_code, response.json())
        super(ApiError, self).__init__(message)



import os
import urllib.parse
import urllib.request

from wavescli import awsadapter


def get_file(remote_uri, local_target_dir, basename=None):

    if remote_uri.startswith('s3://'):
        return awsadapter.get_file(remote_uri, local_target_dir, basename)

    elif remote_uri.startswith('http://') or remote_uri.startswith('https://'):

        if not basename:
            schema = urllib.parse.urlparse(remote_uri)
            basename = os.path.basename(schema.path)

        target_path = os.path.join(local_target_dir, basename)

        response = urllib.request.urlopen(remote_uri)
        with open(target_path, 'wb') as localfile:
            localfile.write(response.read())
        return target_path
    else:
        raise RuntimeError("Couldn't download the URL: {}".format(repr(remote_uri)))



# -*- coding: utf-8 -*-
import tempfile
import os
import shutil
import logging
import logging.config
from pathlib import Path

from celery import Celery
from celery import signals
from celery.utils.log import get_task_logger

from kombu import Exchange, Queue

from wavescli.config import get_config
from wavescli.awsadapter import send_file
from wavescli.downloader import get_file
from wavescli.logger import WAVES_LOGGER_CONFIG


config = get_config()

app = Celery(config.WAVES_CLI_NAME)

# Atencao: pegar mais de 1 mensagem por vez pode ter perda
#          caso o container morra antes de processar todas
app.conf.broker_url = config.BROKER_URL
if config.RESULT_BACKEND_URL:
    app.conf.result_backend = config.RESULT_BACKEND_URL

# Set the worker to fetch 1 message per time
app.conf.worker_prefetch_multiplier = 1
app.conf.task_acks_late = True

app.conf.worker_send_task_events = True
app.conf.task_track_started = True
app.conf.task_send_sent_event = True

app.conf.task_queues = (
    Queue(config.QUEUE_NAME,
          Exchange(config.QUEUE_NAME),
          routing_key=config.QUEUE_NAME),
)

BaseTask = app.create_task_cls()


def get_celery_app():
    signals.before_task_publish.connect(task_updated)
    signals.task_prerun.connect(task_started)
    signals.setup_logging.connect(worker_setup_logging)
    return app


class Values(object):
    pass


class WavesLogger(object):

    def __init__(self, logger, task):
        self._logger = logger
        self._task = task

    def _get_extra(self):
        execution = self._task.identifier if self._task else ''
        task_id = self._task.task_id if self._task else ''
        return extra={
            'execution': execution,
            'task': task_id,
        }

    def info(self, message):
        informations = _get_extra(self)
        self._logger.info(message, extra=informations)

    def debug(self, message):
        informations = _get_extra(self)
        self._logger.debug(message, extra=informations)

    def fatal(self, message):
        informations = _get_extra(self)
        self._logger.fatal(message, extra=informations)

    def warning (self, message):
        informations = _get_extra(self)
        self._logger.warning(message, extra=informations)

    warn = warning


def task_logger():
    celery_logger = get_task_logger
    return celery_logger


def worker_setup_logging(loglevel, logfile, format, colorize, **kwargs):
    logging.config.dictConfigClass(WAVES_LOGGER_CONFIG).configure()


def send_update_execution(
        identifier, task_id, task_name, task_root_id,
        task_parent_id, status=None, inputs=None, args=None, results=None, last_error=None, hostname=None):
    """
    Envia para fila default
    """

    params = (
        identifier,
        task_id,
        task_name,
        task_root_id,
        task_parent_id,
        status,
        inputs,
        args,
        results,
        last_error,
        hostname,
    )
    sig_status = app.signature(
        'awebrunner.update_execution',
        args=params,
        kwargs={},
        queue='celery',
    )
    sig_status.apply_async(countdown=6)


# @signals.before_task_publish.connect
def task_updated(sender=None, headers=None, body=None, **kwargs):
    """
    - Atualizacao de status de tasks existentes
    - Cria tasks em tempo de execucao
    """
    # logger.info("#Step-2(btask) Task published signal received by '{}'".format(sender))

    task_name = headers.get('task')
    task_id = headers.get('id')

    if task_name == 'awebrunner.update_execution':
        # logger.info("#Step-2(btask) Task published signal skipped")
        return True

    args_data, kwargs_data, signatures = body
    identifier = kwargs_data.get('identifier')
    task_root_id = headers.get('root_id')
    task_parent_id = headers.get('parent_id')

    # logger.info("[identifier:{}] #Step-2(btask) Publishing task: {} ({})".format(identifier, task_name, task_id))

    inputs = None
    if type(args_data) == tuple:
        results, inputs, *_ = args_data
        inputs = _handle_inputs(results, inputs['args'] if 'args' in inputs else inputs)

    send_update_execution(
        identifier=identifier,
        task_id=task_id,
        task_name=task_name,
        task_root_id=task_root_id,
        task_parent_id=task_parent_id,
        inputs=inputs if inputs else args_data,
        args=kwargs_data,)


# @signals.task_prerun.connect
def task_started(task_id, task, args, **kwargs):

    # logger.info("#Step-4(btask) Task pre run signal received: {} ".format(task_id))

    kw = kwargs.get('kwargs')
    identifier = kw.get('identifier')

    # logger.info("[identifier:{}] #Step-4(btask) Task pre run sending STARTED: {}".format(identifier, task_id))

    send_update_execution(
        identifier=identifier,
        task_id=task_id,
        task_name=None,
        task_root_id=None,
        task_parent_id=None,
        inputs=None,
        status='STARTED',
        args=kw)


@app.task(name='waves.ping')
def task_ping(seconds=10):
    import time
    time.sleep(seconds)
    return "pong"


def _handle_inputs(results, inputs):

    new_inputs = inputs
    if type(inputs) == dict and inputs.get('inputs'):
        new_inputs = inputs.get('inputs')

    if results is not None:   # and type(inputs) == dict:
        if type(results) == dict:
            new_inputs = results

        elif type(results) == list:
            new_inputs = {
                'items': results
            }

        for key in inputs.keys():
            if key not in new_inputs:
                new_inputs[key] = inputs[key]

    return new_inputs


class WavesBaseTask(BaseTask):
    """Abstract base class for all tasks in my app."""

    abstract = True

    def _initialize(self):
        self._clean_attrs()
        self.inputs = Values()
        self.outputs = Values()

    def _clean_attrs(self):
        for attr in ['call_updated', 'downloaded', 'uploaded', 'on_success_updated']:
            try:
                delattr(self, attr)
            except Exception:
                pass

    def _generate_task_attributes(self, args, kwargs):
        results, inputs = args
        inputs = _handle_inputs(results, inputs)

        self.inputs_values = inputs
        self.outputs_values = kwargs.get('outputs', {})
        self.auto_download = kwargs.get('auto_download', [])
        self.auto_upload = kwargs.get('auto_upload', [])
        self.make_public = kwargs.get('make_public', [])
        self.identifier = kwargs.get('identifier')
        self.bucket = kwargs.get('bucket')

        self.task_id = self.request.id
        self.task_dir = os.path.join(tempfile.gettempdir(), self.task_id)
        self.inputs_dir = os.path.join(self.task_dir, 'inputs')
        self.outputs_dir = os.path.join(self.task_dir, 'outputs')

    def _download_inputs(self):
        if type(self.inputs_values) != dict:
            return

        for item in self.inputs_values.keys():
            self.inputs.__setattr__(item, self.inputs_values.get(item))
            if item not in self.auto_download:
                continue
            try:
                local_file = get_file(
                    self.inputs_values[item], self.inputs_dir)
                self.inputs.__setattr__(item, local_file)

            except Exception as error:
                raise RuntimeError('Error downloading: {}'.format(self.inputs_values.get(item)), error)
        self.downloaded = True

    def _upload_outputs(self, outputs, target):
        for item in self.auto_upload:
            try:

                if item.startswith('items.') and 'items' in outputs:
                    for subitem_dict in outputs['items']:
                        subitem = item.replace('items.', '')
                        local_file_path = self._replace_vars(subitem_dict[subitem])
                        filename = os.path.basename(local_file_path)
                        remote_path = '{}/{}'.format(target, filename)
                        remote_file = send_file(
                            local_file_path, self.bucket, remote_path)
                        subitem_dict[subitem] = remote_file
                else:
                    local_file_path = self._replace_vars(outputs[item])
                    filename = os.path.basename(local_file_path)
                    remote_path = '{}/{}'.format(target, filename)
                    remote_file = send_file(
                        local_file_path, self.bucket, remote_path)
                    outputs[item] = remote_file

            except Exception as error:
                raise RuntimeError('Error uploading: {}'.format(local_file_path), error)
        self.uploaded = True
        return outputs

    def _get_task_state(self):
        if self.request.id:
            return str(app.AsyncResult(self.request.id).state)

    def _update_execution(self, identifier, task_id,
                          inputs=None, params=None, result=None, status=None, last_error=None):
        if not status:
            status = self._get_task_state()

        if status in ['SUCCESS', 'FAILURE']:
            # private_ip = socket.gethostbyname(socket.gethostname())
            private_ip = os.getenv('WORKER_PRIVATE_IP')
            hostname = '{}@{}'.format(self.request.task, private_ip)
            self.info("----> status:{} hostname:{}".format(status, hostname))

        send_update_execution(
            identifier=identifier,
            task_id=task_id,
            task_name=self.request.task,
            task_root_id=self.request.root_id,
            task_parent_id=self.request.parent_id,
            status=status,
            inputs=inputs,
            args=params,
            results=result,
            last_error=last_error,
            hostname=hostname)

    def _create_temp_task_folders(self):
        os.makedirs(self.inputs_dir)
        os.makedirs(self.outputs_dir)

    def _delete_temp_task_folders(self):
        shutil.rmtree(self.task_dir)

    def _get_env_variables(self, kwargs):
        env = kwargs.get('env', {})
        env['TASK_ID'] = self.request.id
        env['INPUTS_DIR'] = self.inputs_dir
        env['OUTPUTS_DIR'] = self.outputs_dir
        env['IDENTIFIER'] = self.identifier
        env['BUCKET'] = self.bucket
        return env

    def __call__(self, *args, **kwargs):
        self._initialize()
        self._generate_task_attributes(args, kwargs)

        if not hasattr(self, 'downloaded'):
            self._create_temp_task_folders()
            self._download_inputs()
        self.info("WAVES CALL")
        return super(WavesBaseTask, self).__call__(*args, **kwargs)

    def on_retry(self, exc, task_id, args, kwargs, einfo):
        super(WavesBaseTask, self).on_retry(exc, task_id, args, kwargs, einfo)

    def on_failure(self, exc, task_id, args, kwargs, einfo):
        error = self.get_task_error_details(exc, task_id, args, kwargs, einfo)
        self._update_execution(
            kwargs['identifier'], task_id, status='FAILURE', last_error=error)
        self.info("WAVES ON FAILURE")
        super(WavesBaseTask, self).on_failure(exc, task_id, args, kwargs, einfo)

    def send_auto_upload_outputs(self, delete_temp_folders=True):
        if hasattr(self, 'uploaded'):
            return self.results

        target = '{}/{}/{}'.format(config.WAVES_RESULTS_PATH, self.identifier, self.task_id)
        self.results = self._upload_outputs(self.results, target)

        if delete_temp_folders:
            self._delete_temp_task_folders()
        self.info("WAVES SEND AUTO UPLOAD")
        return self.results

    def folder_to_zip(self, source_folder, compress_format='zip'):
        """
        Zip the source folder and returns the zip file path

        Usage:
          self.folder_to_zip('/tmp/EXEC1/task1/outputs/MYFOLDER')
          returns '/tmp/EXEC1/task1/outputs/MYFOLDER.zip'
        """
        source_folder = Path(source_folder)
        self.info("WAVES FOLDER TO ZIP")
        return shutil.make_archive(
            str(source_folder),
            compress_format,
            root_dir=str(source_folder.parent),
            base_dir=source_folder.name)

    def on_success(self, retval, task_id, args, kwargs):
        if not hasattr(self, 'results'):
            self.results = retval

        results = self.results
        if not hasattr(self, 'on_success_updated'):
            self._update_execution(
                kwargs['identifier'], self.request.id, status='SUCCESS', result=results)
        self.info("WAVES ON SUCCESS")
        super(WavesBaseTask, self).on_success(results, task_id, args, kwargs)

    def _replace_vars(self, text):
        self.info("WAVES REPLACE VARS")
        if type(self.inputs_values) == dict:
            for item in self.inputs_values.keys():
                in_value = self.inputs_values[item]

                if type(in_value) == dict or type(in_value) == list:
                    continue
                if in_value:
                    original = '${{ ' + 'inputs.{}'.format(item) + ' }}'
                    text = text.replace(original, str(self.inputs.__getattribute__(item)))

        if type(self.outputs_values) == dict:
            for item in self.outputs_values.keys():
                out_value = self.outputs_values[item]
                if type(out_value) == dict or type(out_value) == list:
                    continue
                if out_value:
                    original = '${{ ' + 'outputs.{}'.format(item) + ' }}'
                    text = text.replace(original, str(out_value))
        return text

    def get_task_error_details(self, exc, task_id, args, kwargs, traceback):
        """
        Return the task error based on the exception
        """
        error = '''{}\n{}'''.format(str(exc).strip(), str(traceback).strip())
        return error

    def get_logger(self, logger):
        self._logger = WavesLogger(logger, self)
        return self._logger

    def info(self, message):
        try:
            if not self._logger:
                return
            self._logger.info(message)
        except Exception:
            pass



import os
import boto3

from wavescli.config import get_config

config = get_config()


def send_file(filepath, target_bucket, key):
    """ Upload a file data to s3://target_bucket/file_path/file_name"""
    s3 = _create_boto_client("s3")
    s3.upload_file(filepath, target_bucket, key)
    return "s3://{}/{}".format(target_bucket, key)


def get_file(remote_uri, local_target_dir, basename=None):
    if not os.path.isdir(local_target_dir):
        os.makedirs(local_target_dir)

    s3 = _create_boto_client("s3")

    bucket_name, path = _extract_bucket_and_key(remote_uri)
    if not basename:
        basename = os.path.basename(path)
    target_path = os.path.join(local_target_dir, basename)
    s3.download_file(bucket_name, path, target_path)
    return target_path


def public_url(remote_uri):
    if not remote_uri:
        return None

    bucket, key = _extract_bucket_and_key(remote_uri)
    s3 = _create_boto_client("s3")
    _24hours = 86400
    return s3.generate_presigned_url(
        ClientMethod="get_object",
        Params={
            "Bucket": bucket,
            "Key": key
        },
        ExpiresIn=_24hours,
    )


def update_file_metadata(remote_uri, metadata):
    """ Adiciona metadata em um arquivo existente no S3 """
    bucket_name, key = _extract_bucket_and_key(remote_uri)
    s3 = _create_boto_client("s3")
    response = s3.copy(
        CopySource={
            "Bucket": bucket_name,
            "Key": key,
        },
        Key=key,
        Bucket=bucket_name,
        ExtraArgs={
            "Metadata": metadata,
            "MetadataDirective": "REPLACE",
        }
    )
    return response


def _create_boto_client(name):
    if config.AWS_ENDPOINT_URL:
        return boto3.client(name, endpoint_url=config.AWS_ENDPOINT_URL)
    return boto3.client(name)


def _extract_bucket_and_key(url):
    schema_prefix = "s3://"

    if not url.startswith(schema_prefix):
        raise RuntimeError("Invalid S3 URL: {}".format(repr(url)))
    bucket, key = url[len(schema_prefix):].split("/", 1)
    return bucket, key



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import json
import yaml
import subprocess
import click

from wavescli import VERSION


@click.group()
@click.pass_context
@click.version_option(version=VERSION)
def main(ctx):
    WAVES_URL = os.environ.get('WAVES_URL')
    API_KEY = os.environ.get('API_KEY')

    ctx.obj['config'] = {
        'WAVES_URL': WAVES_URL,
        'API_KEY': API_KEY,
    }


@main.command(name='create')
@click.option('--workflow/--businesstask', required=True, default=True)
@click.argument('yaml_filepath', required=True, type=click.File('r'))
@click.pass_context
def create(ctx, workflow, yaml_filepath):
    """
    Create a workflow/business task from a YAML file
    """
    definition_str = yaml_filepath.read()
    if workflow and definition_str:
        click.secho("   Creating workflow...", fg='green')
        output = ctx.obj.client.create_workflow(definition_str)

    elif not workflow and definition_str:
        click.secho("   Creating businesstask...", fg='green')
        output = ctx.obj.client.register_businesstask(definition_str)

    click.secho(json.dumps(output, indent=2, sort_keys=True), fg='yellow')


@main.command(name='publish')
@click.option('--businesstask', is_flag=True)
@click.argument('yaml_filepath', required=True, type=click.File('r'))
@click.pass_context
def publish(ctx, businesstask, yaml_filepath):
    """
    Publish a business task from a YAML file
    """
    definition_str = yaml_filepath.read()
    if businesstask and definition_str:
        click.secho("   Publishing businesstask...", fg='green')
        new_btask = ctx.obj.client.publish_businesstask(definition_str)
        click.secho(json.dumps(new_btask, indent=2, sort_keys=True), fg='yellow')


@main.command(name='worker')
@click.option('--start/--stop', required=True, default=True)
@click.option('--tasks', required=False, help='The path for the business task tasks.py file')
@click.argument('yaml_filepath', required=True, type=click.File('rb'))
def worker(start, tasks, yaml_filepath):
    """
    Start/Stop worker to receiving messages from Waves broker
    """
    definition = yaml.load(yaml_filepath, Loader=yaml.FullLoader)

    if start and definition:
        start_worker(definition, tasks)
    else:
        stop_worker(definition, tasks)


def start_worker(definition, tasks):
    task_name = definition.get('name')
    task_version = definition.get('version', 'latest')
    tasks_module = definition.get('tasks_module', 'waves.btasks.app')
    if tasks:
        tasks_module = tasks
    default_queue = 'wv_{}@{}'.format(task_name, task_version)
    loglevel = 'INFO'

    concurrency = os.environ.get('CELERY_CONCURRENCY', 1)
    queue = os.environ.get('QUEUE_NAME', default_queue)
    worker_name = os.environ.get('WORKER_PRIVATE_IP', '%h')

    # --detach
    cmd = 'celery -A {} worker --hostname {}@{} --loglevel={} --task-events -Ofair -c {} -Q {}'.format(
        tasks_module, task_name, worker_name, loglevel, concurrency, queue)
    click.secho("   ...Starting worker\n{}".format(cmd), fg='yellow')

    subprocess.call(cmd.split(' '))


def stop_worker(definition, tasks):
    tasks_module = definition.get('tasks_module', 'waves.btasks.app')

    if tasks:
        tasks_module = tasks

    cmd = 'celery -A {} control shutdown'.format(tasks_module)
    click.secho("   ...Stopping worker\n{}".format(cmd), fg='yellow')

    subprocess.call(cmd.split(' '))


@main.command(name='init')
@click.option('--project',
              type=click.Choice(['New', 'Existing'], case_sensitive=False), prompt=True)
def worker_init(project):
    """
    Add waves files
    cookiecutter https://gitlab.spacetimeanalytics.com/waves/bt-template.git -c existing
    """
    click.secho("   ...project{}".format(project), fg='yellow')

    template = 'https://gitlab.spacetimeanalytics.com/waves/bt-template.git'

    existing_project = project.upper() == 'EXISTING'
    cmd = 'cookiecutter {}{}'.format(
        template, ' -f -c existing' if existing_project else '')

    click.secho("   ...Initializing Waves' files\n", fg='yellow')

    subprocess.call(cmd.split(' '))



# -*- coding: utf-8 -*-

import click
from .cli import main
from .apiclient import ApiClient


class CliObject(dict):
    """Classe auxiliar criada para fazer lazy-initialization do
    client da API sem mudar muito a estrutura do CLI"""

    def __init__(self):
        self._client = None
        super(CliObject, self).__init__()

    @property
    def client(self):
        if self._client is None:
            cfg = self['config']
            url = cfg['WAVES_URL']
            key = cfg['API_KEY']
            self._client = ApiClient(url, key)
        return self._client


def run():
    default_context = CliObject()

    try:
        return main(obj=default_context)
    except Exception as exc:
        click.secho(str(exc), fg='red')


if __name__ == '__main__':
    run()



import logging


WAVES_LOGGER_CONFIG = {
    'version': 1,
    'handlers': {
        'default': {
            'level': logging.INFO,
            'formatter': 'standard',
            'class': 'logging.StreamHandler'
        },
        'waves': {
            'level': logging.INFO,
            'formatter': 'waves',
            'class': 'logging.StreamHandler'
        }
    },
    'formatters': {
        'standard': {
            'format': '%(asctime)s [%(levelname)s] %(name)s: %(message)s'
        },
        'waves': {
            'format': '%(asctime)s [%(levelname)s] %(name)s: [execution:%(execution)s] [task:%(task)s] %(message)s'
        }
    },
    'loggers': {
        '': {
            'handlers': ['default'],
            'level': logging.INFO,
            'propagate': True
        },
        'waves': {
            'handlers': ['waves'],
            'level': logging.INFO,
            'propagate': False
        }
    }
}



# -*- coding: utf-8 -*-

import os
from awsvault import Vault


class BaseConfig(object):
    DEBUG = False
    TESTING = False

    AWS_SECRETS = os.getenv('AWS_SECRETS')
    vault = Vault([s.strip() for s in AWS_SECRETS.split(',')] if AWS_SECRETS else [])

    AWS_ENDPOINT_URL = vault.get('AWS_ENDPOINT_URL')

    BROKER_URL = vault.get("BROKER_URL")
    RESULT_BACKEND_URL = vault.get("RESULT_BACKEND_URL")
    WAVES_URL = vault.get("WAVES_URL")
    WAVES_RESULTS_PATH = vault.get('WAVES_RESULTS_PATH', 'waves/results')

    WAVES_CLI_NAME = os.getenv('WAVES_CLI_NAME', 'waves')
    QUEUE_NAME = os.getenv('QUEUE_NAME', 'waves_latest')


class DevelopmentConfig(BaseConfig):
    DEBUG = True


class ProductionConfig(BaseConfig):
    pass


def get_config(env='prod'):

    if env in ['development', 'dev']:
        return DevelopmentConfig()

    return ProductionConfig()
